summaryrefslogtreecommitdiffstats
path: root/src/emu/render.cpp
diff options
context:
space:
mode:
author Vas Crabb <vas@vastheman.com>2021-07-15 04:09:18 +1000
committer Vas Crabb <cuavas@users.noreply.github.com>2021-07-15 13:54:40 +1000
commit37157461313b13a691722b83c87df8d2315457da (patch)
tree8034c6f33776f5a8bfc8f6c69af879975061bd0a /src/emu/render.cpp
parent66554d3b84f5fec60dcf5d896283a1a04487c0e0 (diff)
API cleanups and miscellaneous fixes.
emu/ioport.cpp: Allow controller files to override input sequences for inputs that don't use defaults, and to override the toggle setting for digital inputs. emu/config.cpp: Expose configuration level (mostly matters for controller files), improved verbose diagnostic messages, and moved a few things out of the global and preprocessor namespaces. docs: Added documentation for some controller configuration file features. The device mapping feature documentation will be merged in at some point. util/unicode.cpp, emu/input.cpp: API cleanups.
Diffstat (limited to 'src/emu/render.cpp')
-rw-r--r--src/emu/render.cpp15
1 files changed, 9 insertions, 6 deletions
diff --git a/src/emu/render.cpp b/src/emu/render.cpp
index 9862b0e35db..236a1d56330 100644
--- a/src/emu/render.cpp
+++ b/src/emu/render.cpp
@@ -3057,7 +3057,10 @@ render_manager::render_manager(running_machine &machine)
, m_ui_container(new render_container(*this))
{
// register callbacks
- machine.configuration().config_register("video", config_load_delegate(&render_manager::config_load, this), config_save_delegate(&render_manager::config_save, this));
+ machine.configuration().config_register(
+ "video",
+ configuration_manager::load_delegate(&render_manager::config_load, this),
+ configuration_manager::save_delegate(&render_manager::config_save, this));
// create one container per screen
for (screen_device &screen : screen_device_enumerator(machine.root_device()))
@@ -3312,10 +3315,10 @@ void render_manager::container_free(render_container *container)
// configuration file
//-------------------------------------------------
-void render_manager::config_load(config_type cfg_type, util::xml::data_node const *parentnode)
+void render_manager::config_load(config_type cfg_type, config_level cfg_level, util::xml::data_node const *parentnode)
{
- // we only care about game files with matching nodes
- if ((cfg_type != config_type::GAME) || !parentnode)
+ // we only care about system-specific configuration with matching nodes
+ if ((cfg_type != config_type::SYSTEM) || !parentnode)
return;
// check the UI target
@@ -3368,8 +3371,8 @@ void render_manager::config_load(config_type cfg_type, util::xml::data_node cons
void render_manager::config_save(config_type cfg_type, util::xml::data_node *parentnode)
{
- // we only care about game files
- if (cfg_type != config_type::GAME)
+ // we only save system-specific configuration
+ if (cfg_type != config_type::SYSTEM)
return;
// write out the interface target